# SEC08-BP03: Automate data at rest protection

## Description

Automated encryption.

## Implementation Guidance

- SCPs to enforce encryption
- Default encryption policies
- Automated compliance checks
- Remediation for unencrypted
- Encryption validation

## Risk Level

Medium - Manual encryption is inconsistent.
